"use client";

import { Locale } from "@/i18n/routing";
import { useBasicInfo } from "@/servers/data/use-basicinfo";
import { Mail, MapPin, Phone } from "lucide-react";
import { useLocale, useTranslations } from "next-intl";
import Image from "next/image";

export function ContactButtons() {
	const locale = useLocale() as Locale;
	const t = useTranslations("RequestForEmployment");

	const { texts } = useBasicInfo();

	return (
		<>
			<div className="flex flex-col flex-wrap items-stretch justify-between gap-8 md:flex-row md:items-center">
				<div className="rounded-full bg-custom-background-light px-8 py-3 border-[1px] border-[#DEDEDE]">
					<div className="flex items-center justify-between gap-8">
						<div className="text-[#606676]">
							<p className="mb-1 text-sm">{t("OurEmail")}</p>
							<p>{texts?.footer_email}</p>
						</div>
						<div className="">
							<div
								className="flex h-[54px] w-[54px] items-center justify-center rounded-full bg-[#606676]"
								style={{ boxShadow: "6px 6px 12px 0px #B3BCD2BF" }}
							>
								<Mail color="#fff" />
							</div>
						</div>
					</div>
				</div>

				<div
					className="rounded-full bg-custom-background-light px-8 py-3 border-[1px] border-[#DEDEDE]"
				>
					<div className="flex items-center justify-between gap-8">
						<div className="text-[#606676]">
							<p className="mb-1 text-sm">{t("OurPhoneNumber")}</p>
							<p className="text-left">{texts?.footer_phone}</p>
						</div>
						<div className="">
							<div
								className="flex h-[54px] w-[54px] items-center justify-center rounded-full bg-[#606676]"
								style={{ boxShadow: "6px 6px 12px 0px #B3BCD2BF" }}
							>
								<Phone color="#fff" />
							</div>
						</div>
					</div>
				</div>

				<div
					className="relative overflow-hidden rounded-[999px] bg-[#606676] px-8 py-3"
					style={{ border: "1px solid #DEDEDE" }}
				>
					<div className="flex items-center justify-between gap-8">
						<div className="text-white z-[1]">
							<p className="mb-1 text-sm">{t("OurLocation")}</p>
							<p>{texts?.address_footer[locale]}</p>
						</div>
						<div className="">
							<div
								className="flex h-[54px] w-[54px] items-center justify-center rounded-full bg-white"
								style={{ boxShadow: "12px 12px 24px 0px #00000080" }}
							>
								<MapPin className="text-custom-primary-accent" />
							</div>
						</div>

						<Image src={"/ornament-2.png"} alt="map" className="z-0" fill />
					</div>
				</div>


			</div>
		</>
	);
}
